@@ -20,14 +20,18 @@ OC.L10N.register(
     "Invalid folder" : "مجلد غير صالح",
     "Error while creating the account: " : "حدث خطأ عند إنشاء الحساب:",
     "Unknown error" : "حدث خطأ غير معروف. ",
+    "Error while updating the account: " : "طرأ هناك خطأ أثناء تحديث الحساب :",
     "All inboxes" : "جميع الوارد",
     "you" : "أنت",
     "Send message to {email}" : "أرسل رسالة لـ {email}",
     "Could not load {tag}{name}{endtag}" : "تعذر تحميل {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "حدث خطأ ما عند تحميل {tag}{name}{endtag}",
+    "Could not load your message" : "تعذرت عملية تحميل رسالتك",
+    "Could not load the message" : "تعذرت عملية تحميل الرسالة",
     "{from}\n{subject}" : "{from}\n{subject}",
     "Nextcloud Mail" : "بريد ناكست كلاود",
     "Save" : "حفظ",
+    "Saved" : "تم الإحتفاظ به",
     "Show all folders" : "أظهر جميع المجلدات",
     "Collapse folders" : "طي المجلدات",
     "Error while deleting account." : "حدث خطأ خلال عملية حذف الحساب.",
@@ -40,7 +44,6 @@ OC.L10N.register(
     "Server error" : "خطا في الخادم",
     "An unknown error occurred" : "حدث خلل غير معروف",
     "Opening HTML drafts is not supported yet." : "فتح مسودات HTML غير مدعّم حاليا.",
-    "Draft saved!" : "تم حفظ المسودّة!",
     "Error while importing the calendar event" : "خلل عند استيراد أحداث التقويم",
     "Error while downloading calendar event" : "خلل عند تحميل احداث التقويم",
     "& others" : "و آخرون",
@@ -55,6 +58,7 @@ OC.L10N.register(
     "All" : "الكل",
     "Favorites" : "المفضلة ",
     "Auto detect failed. Please use manual mode." : "فشل في عملية التحقق الآلي. الرجاء استخدام نمط الدليل.",
+    "Updating account failed: " : "فشلت عملية تحديث الحساب :",
     "Creating account failed: " : "فشل في إنشاء الحساب:",
     "Delete permanently" : "حذف بشكل دائم",
     "Error loading message" : "حدث خطأ خلال تحميل الرسالة",
@@ -112,6 +116,9 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "تح حجب هذه الصورة لحماية خصوصيتك",
     "Show images from this sender" : "أظهر الصور من هذا المُرسل",
     "Forward" : "مرر",
+    "No messages in this folder!" : "هذا المجلد خالٍ مِن الرسائل !",
+    "Upload attachment" : "رفع المرفقات",
+    "Add attachment from Files" : "إضافة مرفقات مِن الملفات",
     "Import into calendar" : "إستيراد من التقويم",
     "Download attachment" : "تنزيل الملحق",
     "Save to Files" : "حفظ للـ الملفات"
