@@ -2,6 +2,7 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "Corréu",
+    "Loading accounts" : "Cargando cuentes",
     "Error while loading the accounts." : "Fallu entrín se carguen les cuentes.",
     "Error while loading the selected account." : "Fallu cargando la cuenta esbillada",
     "Can not load this folder." : "Nun pue cargase esta carpeta.",
@@ -23,13 +24,11 @@ OC.L10N.register(
     "you" : "tu",
     "Send message to {email}" : "Unviar mensaje a {email}",
     "Could not load {tag}{name}{endtag}" : "Nun pudo cargase {tag}{name}{endtag}",
-    "We couldn’t load {tag}{name}{endtag}" : "Nun pudo cargase {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Hebo un problema cargando  {tag}{name}{endtag}",
-    "We couldn’t load your message" : "Nun podemos cargar el to mensaxe",
-    "Unable to load the desired message" : "Nun pue cargase'l mensaxe deseáu",
-    "There was a problem loading the message" : "Hebo un problema cargando'l mensaxe",
+    "Could not load your message" : "Nun pudo cargase'l to mensaxe",
     "{from}\n{subject}" : "{from}\n{subject}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n mensaxe nuevu \nde {from}","%n mensaxes nuevos \nde {from}"],
+    "Save" : "Guardar",
     "Show all folders" : "Amosar toles carpetes",
     "Error while deleting account." : "Fallu desaniciando la cuenta",
     "Choose a file to add as attachment" : "Escueyi un ficheru p'amestalu como axuntu",
@@ -41,10 +40,10 @@ OC.L10N.register(
     "Server error" : "Fallu de sirvidor",
     "An unknown error occurred" : "Asocedió un fallu desconocíu",
     "Opening HTML drafts is not supported yet." : "Abrir borradores de HTML ainda nun ta soportáu",
-    "Draft saved!" : "¡Borrador salváu!",
     "No writable calendars found" : "Nun s'atoparon calendarios pa escribir",
     "Error while importing the calendar event" : "Fallu mientres importaben los eventos del calendariu",
     "Error while downloading calendar event" : "Fallu mientres descargaben los eventos del calendariu",
+    "& others" : "y otros",
     "Error while loading messages." : "Fallu cargando mensaxes",
     "Setting up your account" : "Configurando la to cuenta",
     "Inbox" : "Bandexa d'entrada",
@@ -58,7 +57,6 @@ OC.L10N.register(
     "Auto detect failed. Please use manual mode." : "Falló l'autodeteición. Por favor, usa el mou manual.",
     "Creating account failed: " : "Fallu creando la cuenta:",
     "Delete permanently" : "Desaniciar dafechu",
-    "& others" : "y otros",
     "Error loading message" : "Fallu cargando mensaxe",
     "Settings" : "Axustes",
     "Forwarding to %s" : "Reunviando a %s",
@@ -71,7 +69,6 @@ OC.L10N.register(
     "New message" : "Mensaxe nuevu",
     "Account Settings" : "Axustes de cuenta",
     "Aliases" : "Nomatos",
-    "Save" : "Guardar",
     "Search" : "Guetar",
     "Refresh" : "Refrescar",
     "Name" : "Nome",
