@@ -26,6 +26,9 @@ OC.L10N.register(
     "Send message to {email}" : "Nachricht an {email} senden",
     "Could not load {tag}{name}{endtag}" : "Konnte {tag}{name}{endtag} nicht laden",
     "There was a problem loading {tag}{name}{endtag}" : "Beim Laden von {tag}{name}{endtag} ist ein Problem aufgetreten",
+    "Could not load your message" : "Ihre Nachricht konnte nicht geladen werden",
+    "Could not load the desired message" : "Gewünschte Nachricht konnte nicht geladen werden",
+    "Could not load the message" : "Nachricht konnte nicht geladen werden",
     "{from}\n{subject}" : "{from}\n{subject}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n neue Nachricht\nvon {from}","%n neue Nachrichten\nvon {from}"],
     "Nextcloud Mail" : "Nextcloud Mail",
@@ -43,7 +46,6 @@ OC.L10N.register(
     "Server error" : "Serverfehler",
     "An unknown error occurred" : "Unbekannter Fehler aufgetreten",
     "Opening HTML drafts is not supported yet." : "Das Öffnen von HTML-Entwürfen wird noch nicht unterstützt.",
-    "Draft saved!" : "Entwurf gespeichert!",
     "No writable calendars found" : "Keine beschreibbaren Kalender gefunden",
     "Error while importing the calendar event" : "Fehler beim Importieren des Kalenderereignis",
     "Error while downloading calendar event" : "Fehler beim Herunterladen des Kalenderereignis",
@@ -111,6 +113,7 @@ OC.L10N.register(
     "to" : "an",
     "cc" : "cc",
     "bcc" : "bcc",
+    "Note that the mail came from a noreply address so your reply will probably not be read." : "Diese E-Mail wurde von einer No-Reply-Adresse gesendet und Ihre Antwort wird wahrscheinlich nicht gelesen",
     "Subject" : "Betreff",
     "Save all to Files" : "Alles unter Dateien sichern",
     "Add mail account" : "E-Mail-Konto hinzufügen",
