@@ -46,7 +46,6 @@ OC.L10N.register(
     "Server error" : "Server error",
     "An unknown error occurred" : "An unknown error occurred",
     "Opening HTML drafts is not supported yet." : "Opening HTML drafts is not supported yet.",
-    "Draft saved!" : "Draft saved!",
     "No writable calendars found" : "No writable calendars found",
     "Error while importing the calendar event" : "Error whilst importing the calendar event",
     "Error while downloading calendar event" : "Error whilst downloading calendar event",
@@ -114,6 +113,7 @@ OC.L10N.register(
     "to" : "to",
     "cc" : "cc",
     "bcc" : "bcc",
+    "Note that the mail came from a noreply address so your reply will probably not be read." : "Note that the mail came from a noreply address so your reply will probably not be read.",
     "Subject" : "Subject",
     "Save all to Files" : "Save all to Files",
     "Add mail account" : "Add mail account",
