@@ -2,32 +2,27 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "Retpoŝto",
-    "{from}\n{subject}" : "{from}\n{subject}",
-    "_%n new message in {folderName} \nfrom {from}_::_%n new messages in {folderName} \nfrom {from}_" : ["%n nova mesaĝo en {folderName}\nde {from}","%n novaj mesaĝoj en {folderName}\nde {from}"],
     "Error while loading the accounts." : "Eraris ŝargo de la kontoj.",
     "Error while loading the selected account." : "Eraris ŝargo de la elektita konto.",
-    "Error while loading messages." : "Eraris ŝargo de mesaĝoj.",
-    "Unknown error" : "Nekonata eraro",
-    "Error while creating an account: " : "Eraris kreo de konto:",
+    "Error while deleting message." : "Eraris forigo de mesaĝo.",
     "Attachments saved to Files." : "Kunsendaĵoj konserviĝis en Dosierojn.",
     "Attachment saved to Files." : "Kunsendaĵo konserviĝis en Dosierojn.",
     "Error while saving attachments to Files." : "Eraris konservo de kunsendaĵoj en Dosierojn.",
     "Error while saving attachment to Files." : "Eraris konservo de kunsendaĵo en Dosierojn.",
+    "Unknown error" : "Nekonata eraro",
+    "All inboxes" : "Ĉiuj enirkestoj",
+    "you" : "vi",
+    "Send message to {email}" : "Mesaĝi al {email}",
+    "{from}\n{subject}" : "{from}\n{subject}",
+    "Error while deleting account." : "Eraris forigo de konto.",
     "Choose a file to add as attachment" : "Elektu dosieron por aldoni kiel kunsendaĵo",
     "Reply" : "Respondi",
     "Send" : "Sendi",
     "Sending …" : "Sendante...",
     "Message sent!" : "Mesaĝo sendiĝis!",
     "Server error" : "Eraro pri servilo",
-    "you" : "vi",
-    "Send message to {email}" : "Mesaĝi al {email}",
-    "Draft saved!" : "Malneto konserviĝis!",
-    "Loading …" : "Ŝargante...",
-    "Load more …" : "Ŝargante pli...",
-    "Error while deleting message." : "Eraris forigo de mesaĝo.",
-    "Error while deleting account." : "Eraris forigo de konto.",
-    "Connecting" : "Konektante",
-    "Connect" : "Konekti",
+    "& others" : "kaj aliaj",
+    "Error while loading messages." : "Eraris ŝargo de mesaĝoj.",
     "Inbox" : "Enirkesto",
     "Sent" : "Senditujo",
     "Drafts" : "Malnetujo",
@@ -38,9 +33,8 @@ OC.L10N.register(
     "Favorites" : "Pliŝatoj",
     "Creating account failed: " : "Kreo de konto malsukcesis:",
     "Delete permanently" : "Forigi por ĉiam",
-    "& others" : "kaj aliaj",
-    "All inboxes" : "Ĉiuj enirkestoj",
     "Error loading message" : "Eraris ŝargo de mesaĝo",
-    "Continue to %s" : "Daŭri al %s"
+    "Continue to %s" : "Daŭri al %s",
+    "Connect" : "Konekti"
 },
 "nplurals=2; plural=(n != 1);");
