@@ -46,7 +46,6 @@ OC.L10N.register(
     "Server error" : "Error en servidor",
     "An unknown error occurred" : "Un error desconocido ha ocurrido",
     "Opening HTML drafts is not supported yet." : "La apertura de borradores HTML aun no está soportada.",
-    "Draft saved!" : "¡Borrador guardado!",
     "No writable calendars found" : "No se han encontrado calendarios con permiso de escritura",
     "Error while importing the calendar event" : "Error al importar el evento de calendario",
     "Error while downloading calendar event" : "Error al descargar el evento de calendario",
@@ -114,6 +113,7 @@ OC.L10N.register(
     "to" : "para",
     "cc" : "cc",
     "bcc" : "bcc",
+    "Note that the mail came from a noreply address so your reply will probably not be read." : "Nota: el correo viene de una dirección noreply (no responder), por lo que probablemente no será leído.",
     "Subject" : "Asunto",
     "Save all to Files" : "Guardar todo en Archivos",
     "Add mail account" : "Añadir cuenta de correo electrónico",
