@@ -26,6 +26,9 @@ OC.L10N.register(
     "Send message to {email}" : "Enviar mensaje a {email}",
     "Could not load {tag}{name}{endtag}" : "No fue posible cargar {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Se presentó un problema al cargar  {tag}{name}{endtag}",
+    "Could not load your message" : "No fue posible cargar tu mensaje",
+    "Could not load the desired message" : "No fue posible cargar el mensaje deseado",
+    "Could not load the message" : "No fue posible cargar el mensaje",
     "{from}\n{subject}" : "{from}\n{subject}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n mensaje nuevo \nde {from}","%n mensajes nuevos \nde {from}"],
     "Nextcloud Mail" : "Correo Nextcloud",
@@ -43,7 +46,6 @@ OC.L10N.register(
     "Server error" : "Se presentó un error en el servidor",
     "An unknown error occurred" : "Se presentó un error desconocido",
     "Opening HTML drafts is not supported yet." : "Abrir borradores HTML aún no está soportado.",
-    "Draft saved!" : "¡Borrador guardado!",
     "No writable calendars found" : "No se encontraron calendarios editables",
     "Error while importing the calendar event" : "Se presentó un error al importar el evento del calendario",
     "Error while downloading calendar event" : "Se presentó un error al descargar el evento del calendario",
@@ -111,6 +113,7 @@ OC.L10N.register(
     "to" : "para",
     "cc" : "cc",
     "bcc" : "cco",
+    "Note that the mail came from a noreply address so your reply will probably not be read." : "Nota que el correo vino de una dirección no-responda asi que tu respuesta probablemente no sea leida. ",
     "Subject" : "Asunto",
     "Save all to Files" : "Guardar todo a Archivos",
     "Add mail account" : "Agregar cuenta de correo",
