@@ -2,12 +2,11 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "Kirjad",
-    "{from}\n{subject}" : "{from}\n{subject}",
-    "_%n new message in {folderName} \nfrom {from}_::_%n new messages in {folderName} \nfrom {from}_" : ["%n uus sõnum kaustas {folderName} \nsaatja: {from}","%n uut sõnumit kaustas {folderName} \nsaatja: {from}"],
+    "Loading accounts" : "Kontode laadimine",
     "Error while loading the accounts." : "Viga kontode laadimisel",
     "Error while loading the selected account." : "Viga valitud konto laadimisel.",
-    "Error while loading messages." : "Tõrge sõnumite laadimisel.",
-    "Error while loading the selected message." : "Viga valitud sõnumi laadimisel.",
+    "Can not load this folder." : "Seda kausta ei saa laadida.",
+    "Error while deleting message." : "Tõrge sõnumi kustutamisel.",
     "Forwarded message" : "Edastatud sõnum",
     "Choose a folder to store the attachment in" : "Vali kaust, kuhu manus salvestada",
     "Attachments saved to Files." : "Manused on salvestatud failidesse.",
@@ -15,7 +14,13 @@ OC.L10N.register(
     "Error while saving attachments to Files." : "Viga manuste salvestamisel failidesse.",
     "Error while saving attachment to Files." : "Viga manuse salvestamisel failidesse.",
     "Unknown error" : "Tundmatu viga",
-    "Error while creating an account: " : "Tõrge konto loomisel:",
+    "All inboxes" : "Kõik postkastid",
+    "you" : "sina",
+    "Send message to {email}" : "Saada kiri aadressile {email}",
+    "{from}\n{subject}" : "{from}\n{subject}",
+    "Save" : "Salvesta",
+    "Saved" : "Salvestatud",
+    "Show all folders" : "Näita kõiki kaustu",
     "Error while deleting account." : "Tõrge konto kustutamisel.",
     "Choose a file to add as attachment" : "Vali fail, mida manustada",
     "Reply" : "Vasta",
@@ -24,12 +29,8 @@ OC.L10N.register(
     "Message sent!" : "Sõnum on saadetud!",
     "Server error" : "Serveri tõrge",
     "Opening HTML drafts is not supported yet." : "HTML mustandite avamine pole veel toetatud.",
-    "Draft saved!" : "Mustand on salvestatud!",
-    "you" : "sina",
-    "Send message to {email}" : "Saada kiri aadressile {email}",
-    "Error while deleting message." : "Tõrge sõnumi kustutamisel.",
-    "Connecting" : "Ühendamine",
-    "Connect" : "Ühenda",
+    "& others" : "& muud",
+    "Error while loading messages." : "Tõrge sõnumite laadimisel.",
     "Inbox" : "Saaabuvad",
     "Sent" : "Saadetud",
     "Drafts" : "Mustandid",
@@ -38,12 +39,41 @@ OC.L10N.register(
     "Junk" : "Tämpspost",
     "All" : "Kõik",
     "Favorites" : "Lemmikud",
-    "Creating account failed: " : "Konto loomine ebaõnnestus:",
     "Auto detect failed. Please use manual mode." : "Automaatne tuvastus ebaõnnestus. Palun proovi käsitsi.",
+    "Creating account failed: " : "Konto loomine ebaõnnestus:",
     "Delete permanently" : "Kustuta jäädavalt",
-    "& others" : "& muud",
-    "All inboxes" : "Kõik postkastid",
     "Error loading message" : "Tõrge kirja laadimisel",
-    "Forwarding you to %s - click here if you are not automatically redirected within the next few seconds." : "Edasi saamine %s-le - kliki siia kui sind ei suunata automaatselt mõne järgmise sekundi jooksul edasi."
+    "Settings" : "Seaded",
+    "Forwarding to %s" : "Edasta %s",
+    "Delete account" : "Kustuta konto",
+    "Try again" : "Proovi uuesti",
+    "New message" : "Uus sõnum",
+    "Account Settings" : "Konto seaded",
+    "Aliases" : "Aliased",
+    "Mail address" : "E-posti aadress",
+    "Display Name" : "Kuvatav nimi",
+    "Account" : "Konto",
+    "Keyboard shortcuts" : "Klaviatuuri otseteed",
+    "Delete" : "Kustuta",
+    "Search" : "Otsi",
+    "Refresh" : "Värskenda",
+    "Name" : "Nimi",
+    "Mail Address" : "E-posti aadress",
+    "Password" : "Parool",
+    "IMAP Host" : "IMAP server",
+    "STARTTLS" : "STARTTLS",
+    "IMAP Port" : "IMAP port",
+    "IMAP User" : "IMAP kasutaja",
+    "IMAP Password" : "IMAP parool",
+    "SMTP Host" : "SMTP server",
+    "SMTP Port" : "SMTP port",
+    "SMTP User" : "SMTP kasutaja",
+    "SMTP Password" : "SMTP parool",
+    "Connect" : "Ühenda",
+    "from" : "saatja",
+    "to" : "saaja",
+    "cc" : "cc",
+    "bcc" : "bcc",
+    "Subject" : "Teema"
 },
 "nplurals=2; plural=(n != 1);");
