@@ -26,6 +26,9 @@ OC.L10N.register(
     "Send message to {email}" : "Lähetä viesti osoitteeseen {email}",
     "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag} ei voitu ladata",
     "There was a problem loading {tag}{name}{endtag}" : "Ladattaessa {tag}{name}{endtag} ilmeni ongelma",
+    "Could not load your message" : "Viestiä ei voitu ladata",
+    "Could not load the desired message" : "Haluttua viestiä ei voitu ladata",
+    "Could not load the message" : "Viestiä ei voitu ladata",
     "{from}\n{subject}" : "{from}\n{subject}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n uusi viesti \nlähettäjältä {from}","%n uutta viestiä \nlähettäjältä {from}"],
     "Nextcloud Mail" : "Nextcloud-sähköposti",
@@ -43,7 +46,6 @@ OC.L10N.register(
     "Server error" : "Palvelinvirhe",
     "An unknown error occurred" : "Tapahtui tuntematon virhe",
     "Opening HTML drafts is not supported yet." : "HTML-luonnosten avaaminen ei ole vielä tuettu ominaisuus.",
-    "Draft saved!" : "Luonnos tallennettu!",
     "No writable calendars found" : "Kirjoitusoikeudella olevia kalentereita ei löytynyt",
     "Error while importing the calendar event" : "Virhe kalenteritapahtumaa tuotaessa",
     "Error while downloading calendar event" : "Virhe kalenteritapahtumaa ladatessa",
@@ -111,6 +113,7 @@ OC.L10N.register(
     "to" : "Vastaanottaja",
     "cc" : "Kopio",
     "bcc" : "Piilokopio",
+    "Note that the mail came from a noreply address so your reply will probably not be read." : "Huomioi, että viesti saapui noreply-osoitteesta (ns. älä vastaa -osoite), joten vastausviestiäsi tuskin luetaan.",
     "Subject" : "Aihe",
     "Save all to Files" : "Tallenna kaikki tiedostoihin",
     "Add mail account" : "Lisää sähköpostitili",
