@@ -46,7 +46,6 @@ OC.L10N.register(
     "Server error" : "Erreur du serveur",
     "An unknown error occurred" : "Une erreur inconnue est survenue",
     "Opening HTML drafts is not supported yet." : "L'ouverture de brouillons au format HTML n'est pas prise en charge pour le moment.",
-    "Draft saved!" : "Brouillon sauvegardé!",
     "No writable calendars found" : "Aucun calendrier modifiable n'a été trouvé",
     "Error while importing the calendar event" : "Erreur pendant l'importation de l'évènement du calendrier",
     "Error while downloading calendar event" : "Erreur pendant le téléchargement de l'évènement du calendrier",
@@ -114,6 +113,7 @@ OC.L10N.register(
     "to" : "vers",
     "cc" : "cc",
     "bcc" : "bcc",
+    "Note that the mail came from a noreply address so your reply will probably not be read." : "Notez que le mail provient d'une adresse noreply donc votre réponse ne sera sans doute pas lu.",
     "Subject" : "Sujet",
     "Save all to Files" : "Enregistrer tout dans les Fichiers",
     "Add mail account" : "Ajouter un compte mail",
