@@ -20,11 +20,7 @@ OC.L10N.register(
     "All inboxes" : "Sve dolazne",
     "Send message to {email}" : "Pošalji poruku na {email}",
     "Could not load {tag}{name}{endtag}" : "Greška pri učitavanju {tag}{name}{endtag}",
-    "We couldn’t load {tag}{name}{endtag}" : "Neuspjelo učitavanje {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Problem pri učitavanju {tag}{name}{endtag}",
-    "We couldn’t load your message" : "Poruka se nije uspjela učitati.",
-    "Unable to load the desired message" : "Željena poruka se ne može učitati",
-    "There was a problem loading the message" : "Greška pri učitavanju poruke",
     "{from}\n{subject}" : "{from}\n{subject}",
     "Save" : "Spremi",
     "Show all folders" : "Prikaži sve mape",
@@ -38,7 +34,6 @@ OC.L10N.register(
     "Server error" : "Greška poslužitelja",
     "An unknown error occurred" : "Došlo je do nepoznate greške",
     "Opening HTML drafts is not supported yet." : "Otvaranje HTML skica još nije podržano.",
-    "Draft saved!" : "Skica zapisana!",
     "No writable calendars found" : "Nije pronađen nijedan dostupni kalendar",
     "Error while importing the calendar event" : "Greška pri uvozu događaja kalendara",
     "Error while downloading calendar event" : "Greška pri preuzimanju događaja kalendara",
