@@ -46,7 +46,6 @@ OC.L10N.register(
     "Server error" : "Szerver hiba",
     "An unknown error occurred" : "Ismeretlen hiba történt",
     "Opening HTML drafts is not supported yet." : "A HTML vázlatok megnyitása még nem támogatott.",
-    "Draft saved!" : "Vázlat mentve.",
     "No writable calendars found" : "Nem található írható naptár",
     "Error while importing the calendar event" : "Hiba a naptár esemény importálása közben",
     "Error while downloading calendar event" : "Hiba a naptár esemény letöltése közben",
@@ -114,6 +113,7 @@ OC.L10N.register(
     "to" : "címzett",
     "cc" : "másolat",
     "bcc" : "titkos másolat",
+    "Note that the mail came from a noreply address so your reply will probably not be read." : "Vedd figyelembe, hogy egy \"ne válaszolj\" címről jött a levél, így válaszodat valószínűleg nem fogják elolvasni.",
     "Subject" : "Tárgy",
     "Save all to Files" : "Minden mentése a Fájlokba",
     "Add mail account" : "E-mail fiók hozzáadás",
