@@ -2,12 +2,9 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "Email",
-    "{from}\n{subject}" : "{from}\n{subject}",
-    "_%n new message in {folderName} \nfrom {from}_::_%n new messages in {folderName} \nfrom {from}_" : ["%n pesan baru di {folderName} \ndari {from}"],
     "Error while loading the accounts." : "Terjadi kesalahan saat memuat akun.",
     "Error while loading the selected account." : "Terjadi kesalahan saat memuat akun terpilih.",
-    "Error while loading messages." : "Terjadi kesalahan saat memuat pesan.",
-    "Error while loading the selected message." : "Terjadi kesalahan saat memuat pesan terpilih.",
+    "Error while deleting message." : "Terjadi kesalahan saat menghapus pesan.",
     "Forwarded message" : "Pesan Teralihkan",
     "Choose a folder to store the attachment in" : "Pilih folder untuk menyimpan lampiran didalamnya",
     "Attachments saved to Files." : "Lampiran disimpan pada Berkas.",
@@ -15,7 +12,10 @@ OC.L10N.register(
     "Error while saving attachments to Files." : "Terjadi kesalahan saat menyimpan lampiran pada Berkas.",
     "Error while saving attachment to Files." : "Terjadi kesalahan saat menyimpan lampiran pada Berkas.",
     "Unknown error" : "Kesalahan tidak diketahui",
-    "Error while creating an account: " : "Terjadi kesalahan saat memuat sebuah akun:",
+    "All inboxes" : "Semua kotak masuk",
+    "you" : "Anda",
+    "Send message to {email}" : "Kirim pesan ke {email}",
+    "{from}\n{subject}" : "{from}\n{subject}",
     "Error while deleting account." : "Terjadi kesalahan saat menghapus akun.",
     "Choose a file to add as attachment" : "Pilih berkas untuk ditambahkan sebagai lampiran",
     "Reply" : "Balas",
@@ -24,12 +24,8 @@ OC.L10N.register(
     "Message sent!" : "Kirim pesan!",
     "Server error" : "Kesalahan server",
     "Opening HTML drafts is not supported yet." : "Membuka draf HTML masih belum didukung.",
-    "Draft saved!" : "Draf disimpan!",
-    "you" : "Anda",
-    "Send message to {email}" : "Kirim pesan ke {email}",
-    "Error while deleting message." : "Terjadi kesalahan saat menghapus pesan.",
-    "Connecting" : "Menyambungkan",
-    "Connect" : "Sambungkan",
+    "& others" : "& lainnya",
+    "Error while loading messages." : "Terjadi kesalahan saat memuat pesan.",
     "Inbox" : "Kotak masuk",
     "Sent" : "Kirim",
     "Drafts" : "Konsep",
@@ -38,12 +34,10 @@ OC.L10N.register(
     "Junk" : "Sampah",
     "All" : "Semua",
     "Favorites" : "Favorit",
-    "Creating account failed: " : "Gagal membuat akun:",
     "Auto detect failed. Please use manual mode." : "Deteksi otomatis gagal. Mohon gunakan modus manual.",
+    "Creating account failed: " : "Gagal membuat akun:",
     "Delete permanently" : "Hapus secara permanen",
-    "& others" : "& lainnya",
-    "All inboxes" : "Semua kotak masuk",
     "Error loading message" : "Terjadi kesalahan saat memuat pesan",
-    "Forwarding you to %s - click here if you are not automatically redirected within the next few seconds." : "Meneruskan Anda ke %s - klik disini jika Anda tidak secara otomatis dialihkan dalam beberapa detik kemudian."
+    "Connect" : "Sambungkan"
 },
 "nplurals=1; plural=0;");
