@@ -20,15 +20,20 @@ OC.L10N.register(
     "Invalid folder" : "Ógild mappa",
     "Error while creating the account: " : "Villa við að búa til notandaaðgang: ",
     "Unknown error" : "Óþekkt villa",
+    "Error while updating the account: " : "Villa við að uppfæra notandaaðganginn",
     "All inboxes" : "Öll innhólf",
     "you" : "þú",
     "Send message to {email}" : "Senda skilaboð til {email}",
     "Could not load {tag}{name}{endtag}" : "Gat ekki hlaðið inn {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Vandamál kom upp við hlaða inn {tag}{name}{endtag}",
+    "Could not load your message" : "Gat ekki hlaðið inn skilaboðunum þínum",
+    "Could not load the desired message" : "Gat ekki hlaðið inn umbeðnum skilaboðum",
+    "Could not load the message" : "Gat ekki hlaðið inn skilaboðunum",
     "{from}\n{subject}" : "{from}\n{subject}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ný skilaboð \nfrá {from}","%n ný skilaboð \nfrá {from}"],
     "Nextcloud Mail" : "Nextcloud-póstur",
     "Save" : "Vista",
+    "Saved" : "Vistað",
     "Show all folders" : "Birta allar möppur",
     "Collapse folders" : "Fella möppur saman",
     "Error while deleting account." : "Villa kom upp við að eyða aðgangi.",
@@ -41,7 +46,6 @@ OC.L10N.register(
     "Server error" : "Villa frá þjóni",
     "An unknown error occurred" : "Óþekkt villa kom upp",
     "Opening HTML drafts is not supported yet." : "Ekki er hægt að opna HTML-drög - ennþá.",
-    "Draft saved!" : "Drög vistuð!",
     "No writable calendars found" : "Engin skrifanleg dagatöl fundust",
     "Error while importing the calendar event" : "Villa kom upp við að flytja inn dagatalsatburðinn",
     "Error while downloading calendar event" : "Villa kom upp við að sækja dagatalsatburð",
@@ -58,6 +62,7 @@ OC.L10N.register(
     "All" : "Allt",
     "Favorites" : "Eftirlæti",
     "Auto detect failed. Please use manual mode." : "Mistókst að finna sjálkrafa. Notaðu handvirku leiðina.",
+    "Updating account failed: " : "Mistókst að uppfæra notandaaðgang: ",
     "Creating account failed: " : "Mistókst að búa til notandaaðgang: ",
     "Delete permanently" : "Eyða varanlega",
     "Error loading message" : "Villa við hleðslu á skilaboðum",
@@ -75,6 +80,7 @@ OC.L10N.register(
     "Aliases" : "Samheiti",
     "Mail address" : "Tölvupóstfang",
     "Display Name" : "Birtingarnafn",
+    "Account" : "Notandaaðgangur",
     "Keyboard shortcuts" : "Flýtileiðir á lyklaborði",
     "Speed up your Mail experience with these quick shortcuts." : "Flýttu fyrir vinnu þinni með póst með þessum flýtilyklum.",
     "Compose new message" : "Semja ný skilaboð",
@@ -107,9 +113,11 @@ OC.L10N.register(
     "to" : "til",
     "cc" : "cc",
     "bcc" : "bcc",
+    "Note that the mail came from a noreply address so your reply will probably not be read." : "Athugaðu að skilaboðin komu frá ekki-svara netfangi (noreply) þannig að svarið þitt verður líklega ekki lesið.",
     "Subject" : "Viðfangsefni",
     "Save all to Files" : "Vista allt í skrár",
     "Add mail account" : "Bæta við notandaaðgangi",
+    "Use Gravatar and favicon avatars" : "Nota Gravatar og veftáknmyndir (favicon)",
     "No search results for" : "Engar leitarniðurstöður fyrir",
     "The images have been blocked to protect your privacy." : "Lokað hefur verið á myndir til að vernda einkalíf þitt.",
     "Show images from this sender" : "Birta myndir frá þessum sendanda",
