@@ -46,7 +46,6 @@ OC.L10N.register(
     "Server error" : "Errore del server",
     "An unknown error occurred" : "Si è verificato un errore sconosciuto",
     "Opening HTML drafts is not supported yet." : "L'apertura delle bozze HTML non è ancora supportata.",
-    "Draft saved!" : "Bozza salvata!",
     "No writable calendars found" : "Nessun calendario scrivibile trovato",
     "Error while importing the calendar event" : "Errore durante l'importazione dell'evento di calendario",
     "Error while downloading calendar event" : "Errore durante lo scaricamento dell'evento di calendario",
@@ -114,6 +113,7 @@ OC.L10N.register(
     "to" : "a",
     "cc" : "cc",
     "bcc" : "ccn",
+    "Note that the mail came from a noreply address so your reply will probably not be read." : "Nota che il messaggio è arrivato da un indirizzo noreply, perciò la tua risposta non sarà probabilmente letta.",
     "Subject" : "Oggetto",
     "Save all to Files" : "Salva tutto in File",
     "Add mail account" : "Aggiungi account di posta",
