@@ -46,7 +46,6 @@ OC.L10N.register(
     "Server error" : "სერვერის შეცდომა",
     "An unknown error occurred" : "გამოჩნდა ამოუცნობი შეცდომა",
     "Opening HTML drafts is not supported yet." : "HTML მონახაზის გახსნა ჯერ მხარდაჭერილი არაა.",
-    "Draft saved!" : "მონახაზი შენახულია!",
     "No writable calendars found" : "ჩაწერადი კალენდრები ვერ იქნა ნაპოვნი",
     "Error while importing the calendar event" : "კალენდრის მოვლენის იმპორტირებისას წარმოიშვა შეცდომა",
     "Error while downloading calendar event" : "კალენდრის მოვლენის ჩამოტვირთვისას წარმოიშვა შეცდომა",
@@ -114,6 +113,7 @@ OC.L10N.register(
     "to" : "ვის",
     "cc" : "კკ",
     "bcc" : "ბკკ",
+    "Note that the mail came from a noreply address so your reply will probably not be read." : "შენიშნეთ რომ წერილი მიღებულია \"დაუბრუნებელი\" მისამართიდან, ასე რომ თქვენი პასუხი სავარაუდოდ არ იქნება წაკითხული.",
     "Subject" : "სათაური",
     "Save all to Files" : "ყველაფრის ფაილებში შენახვა",
     "Add mail account" : "საფოსტო ანგარიშის დამატება",
