@@ -26,6 +26,9 @@ OC.L10N.register(
     "Send message to {email}" : "{email}(으)로 이메일 보내기",
     "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag}을(를) 불러올 수 없음",
     "There was a problem loading {tag}{name}{endtag}" : "{tag}{name}{endtag}을(를) 불러오는 중 문제 발생",
+    "Could not load your message" : "메시지를 불러올 수 없음",
+    "Could not load the desired message" : "원하는 메시지를 불러올 수 없음",
+    "Could not load the message" : "메시지를 불러올 수 없음",
     "{from}\n{subject}" : "{from}\n{subject}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["새 메일 %n개\n보낸 사람: {from}"],
     "Nextcloud Mail" : "Nextcloud 메일",
@@ -43,7 +46,6 @@ OC.L10N.register(
     "Server error" : "서버 오류",
     "An unknown error occurred" : "알 수 없는 오류가 발생했습니다",
     "Opening HTML drafts is not supported yet." : "HTML 임시 보관 메시지를 여는 것은 지원되지 않습니다.",
-    "Draft saved!" : "임시 보관함에 저장했습니다!",
     "No writable calendars found" : "기록할 수 있는 달력을 찾을 수 없음",
     "Error while importing the calendar event" : "달력 행사를 가져 오는 중 오류 발생",
     "Error while downloading calendar event" : "달력 행사를 다운로드하는 중 오류 발생",
@@ -111,6 +113,7 @@ OC.L10N.register(
     "to" : "받는 사람",
     "cc" : "참조",
     "bcc" : "숨은 참조",
+    "Note that the mail came from a noreply address so your reply will probably not be read." : "발신 전용 주소에서 보낸 이메일이기 때문에 수신자가 답장을 읽지 않을 수도 있습니다.",
     "Subject" : "제목",
     "Save all to Files" : "모두 저장",
     "Add mail account" : "메일 계정 추가",
