@@ -20,15 +20,20 @@ OC.L10N.register(
     "Invalid folder" : "Neteisingas aplankas",
     "Error while creating the account: " : "Klaida kuriant paskyrą: ",
     "Unknown error" : "Nežinoma klaida",
+    "Error while updating the account: " : "Klaida atnaujinant paskyrą: ",
     "All inboxes" : "Visos pašto dėžutės",
     "you" : "jūs",
     "Send message to {email}" : "Nusiųsti žinutę į {email}",
     "Could not load {tag}{name}{endtag}" : "Nepavyko įkelti {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Įvyko klaida bandant parodyti {tag}{name}{endtag}",
+    "Could not load your message" : "Nepavyko įkelti jūsų laiško",
+    "Could not load the desired message" : "Nepavyko įkelti pageidaujamo laiško",
+    "Could not load the message" : "Nepavyko įkelti laiško",
     "{from}\n{subject}" : "{from}\n{subject}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n naujas laiškas \nnuo {from}","%n nauji laiškai \nnuo {from}","%n naujų laiškų \nnuo {from}"],
     "Nextcloud Mail" : "Nextcloud el. paštas",
     "Save" : "Įrašyti",
+    "Saved" : "Įrašyta",
     "Show all folders" : "Rodyti visus aplankus",
     "Collapse folders" : "Suskleisti aplankus",
     "Error while deleting account." : "Klaida, ištrinant paskyrą.",
@@ -41,7 +46,6 @@ OC.L10N.register(
     "Server error" : "Serverio klaida",
     "An unknown error occurred" : "Įvyko nežinoma klaida",
     "Opening HTML drafts is not supported yet." : "HTML juodraščių atvėrimas kol kas nepalaikomas.",
-    "Draft saved!" : "Juodraštis įrašytas!",
     "No writable calendars found" : "Nerasta kalendorių redagavimui",
     "Error while importing the calendar event" : "Klaida, importuojant kalendoriaus įvykį",
     "Error while downloading calendar event" : "Klaida, atsisiunčiant kalendoriaus įvykį",
@@ -58,6 +62,7 @@ OC.L10N.register(
     "All" : "Viskas",
     "Favorites" : "Mėgstamiausi",
     "Auto detect failed. Please use manual mode." : "Automatinis nustatymų aptikimas nepavyko. Įveskite duomenis rankiniu būdu.",
+    "Updating account failed: " : "Paskyros atnaujinimas nepavyko: ",
     "Creating account failed: " : "Paskyros kūrimas nepavyko:",
     "Delete permanently" : "Ištrinti negrįžtamai",
     "Error loading message" : "Klaida, įkeliant laišką",
@@ -75,6 +80,7 @@ OC.L10N.register(
     "Aliases" : "Pseudonimai",
     "Mail address" : "El. pašto adresas",
     "Display Name" : "Rodomas vardas",
+    "Account" : "Paskyra",
     "Keyboard shortcuts" : "Klaviatūros greitieji klavišai",
     "Speed up your Mail experience with these quick shortcuts." : "Padidinkite savo našumą naudodamiesi šiomis nuorodomis.",
     "Compose new message" : "Rašyti naują laišką",
@@ -107,9 +113,11 @@ OC.L10N.register(
     "to" : "į",
     "cc" : "cc",
     "bcc" : "bcc",
+    "Note that the mail came from a noreply address so your reply will probably not be read." : "Turėkite omenyje, kad laiškas atėjo iš adreso, kuris nėra skirtas atsakyti, taigi jūsų atsakymas, tikriausiai, nebus perskaitytas.",
     "Subject" : "Tema",
     "Save all to Files" : "Įrašyti visus į Failus",
     "Add mail account" : "Pridėti pašto paskyrą",
+    "Use Gravatar and favicon avatars" : "Naudoti Gravatar ir svetainių piktogramų avatarus",
     "No search results for" : "Nėra paieškos rezultatų, skirtų",
     "The images have been blocked to protect your privacy." : "Tam, kad būtų apsaugotas jūsų privatumas, paveikslai buvo užblokuoti.",
     "Show images from this sender" : "Rodyti paveikslus nuo šio siuntėjo",
