@@ -8,10 +8,10 @@ OC.L10N.register(
     "Error while deleting message." : "Kļūda dzēšot vēstuli.",
     "Forwarded message" : "Pārsūtīta ziņa",
     "Choose a folder to store the attachment in" : "Izvēlieties mapi, kurā saglabāt pielikumus",
-    "Attachments saved to Files." : "Pielikumi saglabāti failos.",
-    "Attachment saved to Files." : "Pielikumi saglabāti failos.",
-    "Error while saving attachments to Files." : "Kļūda, saglabājot pielikumus failā.",
-    "Error while saving attachment to Files." : "Kļūda, saglabājot pielikumus failā.",
+    "Attachments saved to Files." : "Pielikumi saglabāti datnēs.",
+    "Attachment saved to Files." : "Pielikumi saglabāti datnēs.",
+    "Error while saving attachments to Files." : "Kļūda, saglabājot pielikumus datnēs.",
+    "Error while saving attachment to Files." : "Kļūda, saglabājot pielikumus datnēs.",
     "Message flag could not be set." : "Nevar iestatīt ziņojuma karodziņu.",
     "Could not move message." : "Nevar pārvietot ziņu.",
     "Invalid account" : "Nederīgs konts",
@@ -35,7 +35,6 @@ OC.L10N.register(
     "Server error" : "Servera kļūda",
     "An unknown error occurred" : "Radusies nezināma kļūda",
     "Opening HTML drafts is not supported yet." : "HTML dokumentu projektus atvēršana vēl netiek atbalstīta.",
-    "Draft saved!" : "Melnraksts saglabāts!",
     "No writable calendars found" : "Nav ierakstāmu kalendāru",
     "Error while importing the calendar event" : "Kļūda, importējot kalendāra notikumu",
     "Error while downloading calendar event" : "Kļūda ielādējot kalendāra notikumu",
