@@ -26,6 +26,9 @@ OC.L10N.register(
     "Send message to {email}" : "Send melding til {email}",
     "Could not load {tag}{name}{endtag}" : "Kunne ikke laste {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Det oppstod et problem under lasting av {tag}{name}{endtag}",
+    "Could not load your message" : "Kunne ikke laste meldingene dine",
+    "Could not load the desired message" : "Kunne ikke laste den ønskede meldingen",
+    "Could not load the message" : "Kunne ikka laste meldingen",
     "{from}\n{subject}" : "{from}\n{subject}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ny melding \nfra {from}","%n nye meldinger \nfra {from}"],
     "Nextcloud Mail" : "Nextcloud Mail",
@@ -43,7 +46,6 @@ OC.L10N.register(
     "Server error" : "Tjenerfeil",
     "An unknown error occurred" : "En ukjent feil oppstod",
     "Opening HTML drafts is not supported yet." : "Åpning av HTML-kladd er ikke støttet ennå.",
-    "Draft saved!" : "Kladd lagret!",
     "No writable calendars found" : "Ingen skrivbare kalendere funnet",
     "Error while importing the calendar event" : "Feil ved importering av kalenderhendelse",
     "Error while downloading calendar event" : "Feil ved nedlasting av kalenderhendelse",
@@ -111,6 +113,7 @@ OC.L10N.register(
     "to" : "ti",
     "cc" : "cc",
     "bcc" : "bcc",
+    "Note that the mail came from a noreply address so your reply will probably not be read." : "Vær oppmerksom på at eposten kom fra en \"ikke svar\" adresse slik at ditt svar blir muligens ikke lest.",
     "Subject" : "Emne",
     "Save all to Files" : "Lagre alle i Filer",
     "Add mail account" : "Legg til e-postkonto",
