@@ -20,14 +20,19 @@ OC.L10N.register(
     "Invalid folder" : "Nieprawidłowy folder",
     "Error while creating the account: " : "Błąd podczas tworzenia konta:",
     "Unknown error" : "Nieznany błąd",
+    "Error while updating the account: " : "Błąd podczas aktualizacji konta: ",
     "All inboxes" : "Wszystkie skrzynki odbiorcze",
     "you" : "Ty",
     "Send message to {email}" : "Wyślij wiadomość do {email}",
     "Could not load {tag}{name}{endtag}" : "Nie można załadować {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Wystąpił problem podczas wczytywania {tag}{name}{endtag}",
+    "Could not load your message" : "Nie można załadować wiadomości",
+    "Could not load the desired message" : "Nie można wczytać żądanej wiadomości",
+    "Could not load the message" : "Nie można załadować wiadomości",
     "{from}\n{subject}" : "{from}\n{subject}",
     "Nextcloud Mail" : "Poczta Nextcloud",
     "Save" : "Zapisz",
+    "Saved" : "Zapisano",
     "Show all folders" : "Wyświetl wszystkie foldery",
     "Collapse folders" : "Zwiń foldery",
     "Error while deleting account." : "Błąd podczas usuwania konta.",
@@ -40,7 +45,6 @@ OC.L10N.register(
     "Server error" : "Błąd serwera",
     "An unknown error occurred" : "Wystąpił nieznany błąd",
     "Opening HTML drafts is not supported yet." : "Otwieranie wiadomości roboczych w HTML nie jest jeszcze wspierane.",
-    "Draft saved!" : "Szkic został zapisany!",
     "No writable calendars found" : "Nie znaleziono zapisywalnych kalendarzy.",
     "Error while importing the calendar event" : "Wystąpił błąd podczas importowania zdarzenia z kalendarza",
     "Error while downloading calendar event" : "Wystąpił błąd podczas pobierania zdarzenia z kalendarza",
@@ -57,6 +61,7 @@ OC.L10N.register(
     "All" : "Wszystkie",
     "Favorites" : "Ulubione",
     "Auto detect failed. Please use manual mode." : "Autowykrywanie nie powiodło się. Proszę użyć trybu ręcznego.",
+    "Updating account failed: " : "Błąd aktualizacji konta: ",
     "Creating account failed: " : "Utworzenie konta nie powiodło się:",
     "Delete permanently" : "Trwale usuń",
     "Error loading message" : "Błąd podczas ładowania wiadomości",
@@ -74,6 +79,7 @@ OC.L10N.register(
     "Aliases" : "Aliasy",
     "Mail address" : "Adres mailowy",
     "Display Name" : "Wyświetlana nazwa",
+    "Account" : "Konto",
     "Keyboard shortcuts" : "Skróty klawiaturowe",
     "Speed up your Mail experience with these quick shortcuts." : "Aby przyspieszyć korzystanie z Poczty użyj tych skrótów.",
     "Compose new message" : "Napisz nową wiadomość",
@@ -106,9 +112,11 @@ OC.L10N.register(
     "to" : "do",
     "cc" : "cc",
     "bcc" : "bcc",
+    "Note that the mail came from a noreply address so your reply will probably not be read." : "Zauważ, że mail przyszedł z adresu noreply, stąd Twoja odpowiedź na tą wiadomość prawdopodobnie nie zostanie odczytana.",
     "Subject" : "Temat",
     "Save all to Files" : "Zapisz wszystko do plików",
     "Add mail account" : "Dodaj konto mailowe",
+    "Use Gravatar and favicon avatars" : "Używaj awatarów Gravatar i favicon",
     "No search results for" : "Brak wyników wyszukiwania",
     "The images have been blocked to protect your privacy." : "Obrazy zostały zablokowane by chronić Twoją prywatność.",
     "Show images from this sender" : "Zobacz zdjęcia od tego nadawcy",
