@@ -46,7 +46,6 @@ OC.L10N.register(
     "Server error" : "Erro no servidor",
     "An unknown error occurred" : "Ocorreu um erro desconhecido",
     "Opening HTML drafts is not supported yet." : "A abertura de rascunhos do HTML ainda não é suportada.",
-    "Draft saved!" : "Rascunho salvo!",
     "No writable calendars found" : "Não foi encontrado nenhum calendário que possa ser editado",
     "Error while importing the calendar event" : "Erro ao importar o evento de calendário",
     "Error while downloading calendar event" : "Erro ao baixar evento de calendário",
@@ -114,6 +113,7 @@ OC.L10N.register(
     "to" : "para",
     "cc" : "cc",
     "bcc" : "cco",
+    "Note that the mail came from a noreply address so your reply will probably not be read." : "Observe que o email veio de um endereço no-reply então sua resposta provavelmente não será lida.",
     "Subject" : "Assunto",
     "Save all to Files" : "Salvar tudo para Arquivos",
     "Add mail account" : "Adicionar conta de e-mail",
