@@ -2,12 +2,9 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "Correio",
-    "{from}\n{subject}" : "{from}\n{subject}",
-    "_%n new message in {folderName} \nfrom {from}_::_%n new messages in {folderName} \nfrom {from}_" : ["%n nova mensagem na pasta {folderName} \nenviada por {from}","%n novas mensagens na pasta {folderName}\nenviadas por {from}"],
     "Error while loading the accounts." : "Erro durante o carregamento das contas.",
     "Error while loading the selected account." : "Erro durante o carregamento da conta seleccionada.",
-    "Error while loading messages." : "Erro durante o carregamento das mensagens.",
-    "Error while loading the selected message." : "Erro durante o carregamento da mensagem selecionada.",
+    "Error while deleting message." : "Erro durante a eliminação da mensagem.",
     "Forwarded message" : "Mensagem reencaminhada",
     "Choose a folder to store the attachment in" : "Escolha uma pasta para guardar o anexo",
     "Attachments saved to Files." : "Anexos guardados em Ficheiros.",
@@ -17,7 +14,10 @@ OC.L10N.register(
     "Invalid account" : "Conta inválida",
     "Invalid folder" : "Pasta inválida",
     "Unknown error" : "Erro desconhecido",
-    "Error while creating an account: " : "Erro durante a criação da conta:",
+    "All inboxes" : "Todas as caixas de entrada",
+    "you" : "Você",
+    "Send message to {email}" : "Enviar mensagem para {email}",
+    "{from}\n{subject}" : "{from}\n{subject}",
     "Show all folders" : "Mostrar todas as pastas",
     "Collapse folders" : "Ocultar pastas",
     "Error while deleting account." : "Erro durante a eliminação da conta.",
@@ -28,15 +28,11 @@ OC.L10N.register(
     "Message sent!" : "Mensagem enviada!",
     "Server error" : "Erro do servidor",
     "Opening HTML drafts is not supported yet." : "Ainda não é suportada a abertura de rascunhos em HTML.",
-    "Draft saved!" : "Rascunho guardado!",
-    "you" : "Você",
-    "Send message to {email}" : "Enviar mensagem para {email}",
     "No writable calendars found" : "Não foram encontrados calendários graváveis",
     "Error while importing the calendar event" : "Erro durante a importação de evento de calendário",
     "Error while downloading calendar event" : "Erro durante a transferência de evento de calendário",
-    "Error while deleting message." : "Erro durante a eliminação da mensagem.",
-    "Connecting" : "A ligar",
-    "Connect" : "Ligar",
+    "& others" : "e outros",
+    "Error while loading messages." : "Erro durante o carregamento das mensagens.",
     "Inbox" : "Caixa de Entrada",
     "Sent" : "Enviada",
     "Drafts" : "Rascunhos",
@@ -45,13 +41,13 @@ OC.L10N.register(
     "Junk" : "Lixo",
     "All" : "Tudo",
     "Favorites" : "Favoritos",
-    "Creating account failed: " : "Não foi possível criar a conta:",
     "Auto detect failed. Please use manual mode." : "A deteção automática falhou. Por favor, utilize o modo manual",
+    "Creating account failed: " : "Não foi possível criar a conta:",
     "Delete permanently" : "Eliminar permanentemente",
-    "& others" : "e outros",
-    "All inboxes" : "Todas as caixas de entrada",
     "Error loading message" : "Erro ao carregar a mensagem",
+    "Click here if you are not automatically redirected within the next few seconds." : "Clique aqui se não for automaticamente redireccionado dentro de segundos.",
     "Redirect" : "Redirecionar",
-    "Continue to %s" : "Continuar para %s"
+    "Continue to %s" : "Continuar para %s",
+    "Connect" : "Ligar"
 },
 "nplurals=2; plural=(n != 1);");
