@@ -2,12 +2,10 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "Elektronska pošta",
-    "{from}\n{subject}" : "{from}\n{subject}",
-    "_%n new message in {folderName} \nfrom {from}_::_%n new messages in {folderName} \nfrom {from}_" : ["%n novo sporočilo v {folderName} \nod {from}","%n novi sporočili v {folderName} \nod {from}","%n nova sporočila v {folderName} \nod {from}","%n novih sporočil v {folderName} \nod {from}"],
     "Error while loading the accounts." : "Prišlo je do napake med nalaganjem računa.¸",
     "Error while loading the selected account." : "Prišlo je do napake med nalaganjem izbranega računa.",
-    "Error while loading messages." : "Prišlo je do napake nalaganja sporočil.",
-    "Error while loading the selected message." : "Napaka med nalaganjem izbranih sporočil",
+    "Searching for {query}" : "Iščem {query}",
+    "Error while deleting message." : "Napaka med brisanjem sporočila.",
     "Forwarded message" : "Posreduj sporočilo",
     "Choose a folder to store the attachment in" : "Izbor mape za shranjevanje prilog.",
     "Attachments saved to Files." : "Priloge so shranjene med datoteke.",
@@ -15,10 +13,15 @@ OC.L10N.register(
     "Error while saving attachments to Files." : "Prišlo je do napake med shranjevanjem datoteke v mapo.",
     "Error while saving attachment to Files." : "Prišlo je do napake med shranjevanjem datotek v mapo.",
     "Message flag could not be set." : "Zastavice sporočila ni mogoče nastavit.",
+    "Could not move message." : "Ne morem premakniti sporočila.",
     "Invalid account" : "Neveljaven račun",
     "Invalid folder" : "Neveljavna mapa",
     "Unknown error" : "Neznana napaka",
-    "Error while creating an account: " : "Prišlo je do napake med ustvarjanjem računa:",
+    "All inboxes" : "Vsi predali",
+    "you" : "vi",
+    "Send message to {email}" : "Pošlji sporočilo na {email}",
+    "Could not load {tag}{name}{endtag}" : "Ne morem naložiti {tag}{name}{endtag}",
+    "{from}\n{subject}" : "{from}\n{subject}",
     "Show all folders" : "Pokaži vse mape",
     "Collapse folders" : "Zloži mape",
     "Error while deleting account." : "Prišlo je do napake med brisanjem računa.",
@@ -29,15 +32,11 @@ OC.L10N.register(
     "Message sent!" : "Sporočilo je poslano!",
     "Server error" : "Napaka strežnika",
     "Opening HTML drafts is not supported yet." : "Odpiranje osnutkov sporočil v zapisu HTML še ni podprto.",
-    "Draft saved!" : "Osnutek sporočila je shranjen!",
-    "you" : "vi",
-    "Send message to {email}" : "Pošlji sporočilo na {email}",
     "No writable calendars found" : "Ni najdenih zapisljivih koledarjev.",
     "Error while importing the calendar event" : "Napaka med uvažanjem dogodka koledarja",
     "Error while downloading calendar event" : "Napaka med prejemanjem dogodka koledarja",
-    "Error while deleting message." : "Napaka med brisanjem sporočila.",
-    "Connecting" : "Poteka vzpostavljanje povezave ...",
-    "Connect" : "Poveži",
+    "& others" : "in drugo",
+    "Error while loading messages." : "Prišlo je do napake nalaganja sporočil.",
     "Inbox" : "Dohodna pošta",
     "Sent" : "Poslano",
     "Drafts" : "Osnutki",
@@ -46,15 +45,17 @@ OC.L10N.register(
     "Junk" : "Neželena pošta",
     "All" : "Vse",
     "Favorites" : "Priljubljene",
-    "Creating account failed: " : "Ustvarjanje računa je spodletelo:",
     "Auto detect failed. Please use manual mode." : "Samodejno zaznavanje je spodletelo. Zaznavo bo treba izvesti ročno.",
+    "Creating account failed: " : "Ustvarjanje računa je spodletelo:",
     "Delete permanently" : "Izbriši dokončno",
-    "& others" : "in drugo",
-    "All inboxes" : "Vsi predali",
     "Error loading message" : "Napaka nalaganja sporočila",
+    "Settings" : "Nastavitve",
     "Redirect" : "Preusmeri",
     "The link leads to %s" : "Povezava vodi na %s",
     "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Če ne želite obiskati te strani, se lahko vrnete na <a href=\"%s\">pošto</a>.",
-    "Continue to %s" : "Nadaljuj na %s"
+    "Continue to %s" : "Nadaljuj na %s",
+    "New message" : "Novo obvestilo",
+    "Mail address" : "Elektronski naslov",
+    "Connect" : "Poveži"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
