@@ -37,7 +37,6 @@ OC.L10N.register(
     "Server error" : "Gabim shërbyesi",
     "An unknown error occurred" : "Ndodhi një gabim i panjohur",
     "Opening HTML drafts is not supported yet." : "Hapja e skicave HTML nuk mbulohet ende.",
-    "Draft saved!" : "Skica u ruajt!",
     "No writable calendars found" : "S’u gjetën kalendarë të shkruajtshëm",
     "Error while importing the calendar event" : "Gabim gjatë importimit të veprimtarisë së kalendarit",
     "Error while downloading calendar event" : "Gabim gjatë shkarkimit të veprimtarisë së kalendarit",
@@ -70,6 +69,7 @@ OC.L10N.register(
     "Aliases" : "Emërtimet",
     "Mail address" : "Adresa e postës elektronike",
     "Display Name" : "Trego Emrin",
+    "Account" : "Llogari",
     "Keyboard shortcuts" : "Shkurtoret e tastierës",
     "Speed up your Mail experience with these quick shortcuts." : "Përmirësoni përvojën tuaj në Mail me këto shkurtore të shpejta.",
     "Newer message" : "Mesazhe më të reja",
@@ -108,6 +108,8 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "Imazhet janë bllokuar për të mbrojtur privatësinë tuaj.",
     "Show images from this sender" : "Trego imazhet nga ky dërgues",
     "Forward" : "Ridrejto",
+    "No messages in this folder!" : "Asnjë mesazh në këtë dosje!",
+    "Upload attachment" : "Ngarko bashkëngjitje",
     "Import into calendar" : "Importo në kalendar",
     "Download attachment" : "Shkarko bashkëlidhjen",
     "Save to Files" : "Ruaje te Skedarët"
