@@ -46,7 +46,6 @@ OC.L10N.register(
     "Server error" : "Грешка на серверу",
     "An unknown error occurred" : "Десила се непозната грешка",
     "Opening HTML drafts is not supported yet." : "Отварање HTML нацрта још није подржано.",
-    "Draft saved!" : "Нацрт сачуван!",
     "No writable calendars found" : "Нема календара у који је могуће писање",
     "Error while importing the calendar event" : "Грешка приликом увоза догађаја из календара",
     "Error while downloading calendar event" : "Грешка приликом скидања догађаја из календара",
@@ -114,6 +113,7 @@ OC.L10N.register(
     "to" : "за",
     "cc" : "индиго копија",
     "bcc" : "невидљива индиго копија",
+    "Note that the mail came from a noreply address so your reply will probably not be read." : "Ова е-пошта је стигла са адресе на којој има \"noreply\", што значи да вероватно неће бити прочитана ако одговорите на њу.",
     "Subject" : "Наслов",
     "Save all to Files" : "Сачувај све у фајлове",
     "Add mail account" : "Додај налог е-поште",
