@@ -20,11 +20,15 @@ OC.L10N.register(
     "Invalid folder" : "Felaktig mapp",
     "Error while creating the account: " : "Fel när kontot skulle skapas:",
     "Unknown error" : "Okänt fel",
+    "Error while updating the account: " : "Fel medan kontot uppdaterades:",
     "All inboxes" : "alla inkorgar",
     "you" : "du",
     "Send message to {email}" : "Skicka meddelande till {email}",
     "Could not load {tag}{name}{endtag}" : "Kunde inte ladda {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Det blev ett problem när vi skulle ladda {tag}{name}{endtag}",
+    "Could not load your message" : "Kunde inte ladda ditt meddelande",
+    "Could not load the desired message" : "Kunde inte ladda önskat meddelande",
+    "Could not load the message" : "Kunde inte ladda meddelandet",
     "{from}\n{subject}" : "{från}\n{ämne}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nytt meddelande \nfrån {from}","%n nya meddelanden \nfrån {from}"],
     "Nextcloud Mail" : "Nextcloud Mail",
@@ -41,7 +45,6 @@ OC.L10N.register(
     "Server error" : "Serverfel",
     "An unknown error occurred" : "Ett okänt fel uppstod",
     "Opening HTML drafts is not supported yet." : "Att öppna HTML-utkast stöds inte än.",
-    "Draft saved!" : "Utkast sparat!",
     "No writable calendars found" : "Inga skrivbara kalendrar hittade",
     "Error while importing the calendar event" : "Fel vid import av kalenderhändelse",
     "Error while downloading calendar event" : "Fel vid nedladdning av kalenderhändelse",
