@@ -46,7 +46,6 @@ OC.L10N.register(
     "Server error" : "Sunucu sorunu",
     "An unknown error occurred" : "Bilinmeyen bir sorun çıktı",
     "Opening HTML drafts is not supported yet." : "HTML taslaklarının açılması henüz desteklenmiyor.",
-    "Draft saved!" : "Taslak kaydedildi!",
     "No writable calendars found" : "Yazılabilecek bir takvim bulunamadı",
     "Error while importing the calendar event" : "Takvim etkinliği içe aktarılırken sorun çıktı",
     "Error while downloading calendar event" : "Takvim etkinliği indirilirken sorun çıktı",
@@ -114,6 +113,7 @@ OC.L10N.register(
     "to" : "kime",
     "cc" : "kopya",
     "bcc" : "gizli kopya",
+    "Note that the mail came from a noreply address so your reply will probably not be read." : "Posta noreply adresinden gönderildiğinden yanıtınızın okunmayabileceğini unutmayın",
     "Subject" : "Konu",
     "Save all to Files" : "Tümünü dosyalara kaydet",
     "Add mail account" : "Posta hesabi ekle",
