@@ -20,6 +20,7 @@ OC.L10N.register(
     "Invalid folder" : "无效的文件夹",
     "Error while creating the account: " : "创建账户时出错：",
     "Unknown error" : "未知错误",
+    "Error while updating the account: " : "更新账户时出错：",
     "All inboxes" : "所有收件箱",
     "you" : "您",
     "Send message to {email}" : "发送消息至 {email}",
@@ -42,7 +43,6 @@ OC.L10N.register(
     "Server error" : "服务器错误",
     "An unknown error occurred" : "遇到未知错误",
     "Opening HTML drafts is not supported yet." : "暂时未能打开HTML格式的草稿，请见谅。",
-    "Draft saved!" : "草稿已保存！",
     "No writable calendars found" : "未找到可写的日历",
     "Error while importing the calendar event" : "导入日历事件错误",
     "Error while downloading calendar event" : "下载日历事件错误",
@@ -59,6 +59,7 @@ OC.L10N.register(
     "All" : "全部",
     "Favorites" : "收藏",
     "Auto detect failed. Please use manual mode." : "自动检测失败，请使用手动模式。",
+    "Updating account failed: " : "更新账户失败：",
     "Creating account failed: " : "未能创建账户：",
     "Delete permanently" : "永久删除",
     "Error loading message" : "载入电邮时发生错误",
