@@ -28,21 +28,20 @@
 
 namespace OCA\Mail\Controller;
 
-use OCA\Mail\Exception\ServiceException;
+use OCA\Mail\Account;
+use OCA\Mail\Contracts\IMailManager;
 use OCA\Mail\Http\AttachmentDownloadResponse;
 use OCA\Mail\Http\HtmlResponse;
 use OCA\Mail\Model\IMAPMessage;
 use OCA\Mail\Service\AccountService;
-use OCA\Mail\Service\IAccount;
 use OCA\Mail\Service\IMailBox;
 use OCA\Mail\Service\Logger;
-use OCA\Mail\Service\UnifiedAccount;
 use OCP\AppFramework\Controller;
 use OCP\AppFramework\Db\DoesNotExistException;
-use OCP\AppFramework\Http;
 use OCP\AppFramework\Http\ContentSecurityPolicy;
 use OCP\AppFramework\Http\JSONResponse;
 use OCP\AppFramework\Http\TemplateResponse;
+use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\Files\Folder;
 use OCP\Files\IMimeTypeDetector;
 use OCP\IL10N;
@@ -54,6 +53,9 @@ class MessagesController extends Controller {
 	/** @var AccountService */
 	private $accountService;
 
+	/** @var IMailManager */
+	private $mailManager;
+
 	/** @var string */
 	private $currentUserId;
 
@@ -72,9 +74,12 @@ class MessagesController extends Controller {
 	/** @var IURLGenerator */
 	private $urlGenerator;
 
-	/** @var IAccount[] */
+	/** @var Account[] */
 	private $accounts = [];
 
+	/** @var ITimeFactory */
+	private $timeFactory;
+
 	/**
 	 * @param string $appName
 	 * @param IRequest $request
@@ -85,16 +90,12 @@ class MessagesController extends Controller {
 	 * @param IL10N $l10n
 	 * @param IMimeTypeDetector $mimeTypeDetector
 	 * @param IURLGenerator $urlGenerator
+	 * @param ITimeFactory $timeFactory
 	 */
-	public function __construct($appName,
-								IRequest $request,
-								AccountService $accountService,
-								$UserId,
-								$userFolder,
-								Logger $logger,
-								IL10N $l10n,
-								IMimeTypeDetector $mimeTypeDetector,
-								IURLGenerator $urlGenerator) {
+	public function __construct($appName, IRequest $request,
+		AccountService $accountService, IMailManager $mailManager, $UserId,
+		$userFolder, Logger $logger, IL10N $l10n, IMimeTypeDetector $mimeTypeDetector,
+		IURLGenerator $urlGenerator, ITimeFactory $timeFactory) {
 		parent::__construct($appName, $request);
 		$this->accountService = $accountService;
 		$this->currentUserId = $UserId;
@@ -103,24 +104,21 @@ class MessagesController extends Controller {
 		$this->l10n = $l10n;
 		$this->mimeTypeDetector = $mimeTypeDetector;
 		$this->urlGenerator = $urlGenerator;
+		$this->timeFactory = $timeFactory;
+		$this->mailManager = $mailManager;
 	}
 
 	/**
 	 * @NoAdminRequired
+	 * @TrapError
 	 *
 	 * @param int $accountId
 	 * @param string $folderId
 	 * @param int $cursor
 	 * @param string $filter
-	 * @param array $ids
 	 * @return JSONResponse
 	 */
-	public function index($accountId, $folderId, $cursor = null, $filter=null, $ids=null) {
-		if (!is_null($ids)) {
-			$ids = explode(',', $ids);
-
-			return $this->loadMultiple($accountId, $folderId, $ids);
-		}
+	public function index($accountId, $folderId, $cursor = null, $filter = null) {
 		$mailBox = $this->getFolder($accountId, $folderId);
 
 		$this->logger->debug("loading messages of folder <$folderId>");
@@ -132,7 +130,7 @@ class MessagesController extends Controller {
 
 		$json = array_map(function($j) use ($mailBox) {
 			if ($mailBox->getSpecialRole() === 'trash') {
-				$j['delete'] = (string)$this->l10n->t('Delete permanently');
+				$j['delete'] = (string) $this->l10n->t('Delete permanently');
 			}
 			return $j;
 		}, $messages);
@@ -153,14 +151,8 @@ class MessagesController extends Controller {
 		$json = $this->enhanceMessage($accountId, $folderId, $id, $message, $mailBox);
 
 		// Unified inbox hack
+		// TODO: evalue whether this is still in use on the client side
 		$messageId = $id;
-		if ($accountId === UnifiedAccount::ID) {
-			// Add accountId, folderId for unified inbox replies
-			list($accountId, $messageId) = json_decode(base64_decode($id));
-			$account = $this->getAccount($accountId);
-			$inbox = $account->getInbox();
-			$folderId = base64_encode($inbox->getFolderId());
-		}
 		$json['messageId'] = $messageId;
 		$json['accountId'] = $accountId;
 		$json['folderId'] = $folderId;
@@ -171,6 +163,7 @@ class MessagesController extends Controller {
 
 	/**
 	 * @NoAdminRequired
+	 * @TrapError
 	 *
 	 * @param int $accountId
 	 * @param string $folderId
@@ -178,16 +171,12 @@ class MessagesController extends Controller {
 	 * @return JSONResponse
 	 */
 	public function show($accountId, $folderId, $id) {
-		try {
-			$json = $this->loadMessage($accountId, $folderId, $id);
-		} catch (DoesNotExistException $ex) {
-			return new JSONResponse([], 404);
-		}
-		return new JSONResponse($json);
+		return new JSONResponse($this->loadMessage($accountId, $folderId, $id));
 	}
 
 	/**
 	 * @NoAdminRequired
+	 * @TrapError
 	 *
 	 * @param int $accountId
 	 * @param string $folderId
@@ -197,19 +186,18 @@ class MessagesController extends Controller {
 	 * @return JSONResponse
 	 */
 	public function move($accountId, $folderId, $id, $destAccountId, $destFolderId) {
-		try {
-			$this->accountService->moveMessage($accountId, $folderId, $id, $destAccountId, $destFolderId, $this->currentUserId);
-		} catch (ServiceException $ex) {
-			return new JSONResponse([
-				'error' => $ex->getMessage(),
-			], 500);
-		}
+		$srcAccount = $this->accountService->find($this->currentUserId, $accountId);
+		$dstAccount = $this->accountService->find($this->currentUserId,
+			$destAccountId);
+		$this->mailManager->moveMessage($srcAccount, base64_decode($folderId), $id,
+			$dstAccount, base64_decode($destFolderId));
 		return new JSONResponse();
 	}
 
 	/**
 	 * @NoAdminRequired
 	 * @NoCSRFRequired
+	 * @TrapError
 	 *
 	 * @param int $accountId
 	 * @param string $folderId
@@ -221,8 +209,10 @@ class MessagesController extends Controller {
 			$mailBox = $this->getFolder($accountId, $folderId);
 
 			$m = $mailBox->getMessage($messageId, true);
-			$html = $m->getHtmlBody($accountId, $folderId, $messageId, function($cid) use ($m){
-				$match = array_filter($m->attachments, function($a) use($cid){
+			$html = $m->getHtmlBody($accountId, $folderId, $messageId,
+				function($cid) use ($m) {
+				$match = array_filter($m->attachments,
+					function($a) use($cid) {
 					return $a['cid'] === $cid;
 				});
 				$match = array_shift($match);
@@ -244,18 +234,20 @@ class MessagesController extends Controller {
 			$htmlResponse->setContentSecurityPolicy($policy);
 
 			// Enable caching
-			$htmlResponse->cacheFor(60 * 60);
+			$htmlResponse->setCacheHeaders(60 * 60, $this->timeFactory);
 			$htmlResponse->addHeader('Pragma', 'cache');
 
 			return $htmlResponse;
-		} catch(\Exception $ex) {
-			return new TemplateResponse($this->appName, 'error', ['message' => $ex->getMessage()], 'none');
+		} catch (\Exception $ex) {
+			return new TemplateResponse($this->appName, 'error',
+				['message' => $ex->getMessage()], 'none');
 		}
 	}
 
 	/**
 	 * @NoAdminRequired
 	 * @NoCSRFRequired
+	 * @TrapError
 	 *
 	 * @param int $accountId
 	 * @param string $folderId
@@ -263,19 +255,19 @@ class MessagesController extends Controller {
 	 * @param string $attachmentId
 	 * @return AttachmentDownloadResponse
 	 */
-	public function downloadAttachment($accountId, $folderId, $messageId, $attachmentId) {
+	public function downloadAttachment($accountId, $folderId, $messageId,
+		$attachmentId) {
 		$mailBox = $this->getFolder($accountId, $folderId);
 
 		$attachment = $mailBox->getAttachment($messageId, $attachmentId);
 
 		return new AttachmentDownloadResponse(
-			$attachment->getContents(),
-			$attachment->getName(),
-			$attachment->getType());
+			$attachment->getContents(), $attachment->getName(), $attachment->getType());
 	}
 
 	/**
 	 * @NoAdminRequired
+	 * @TrapError
 	 *
 	 * @param int $accountId
 	 * @param string $folderId
@@ -284,20 +276,21 @@ class MessagesController extends Controller {
 	 * @param string $targetPath
 	 * @return JSONResponse
 	 */
-	public function saveAttachment($accountId, $folderId, $messageId, $attachmentId, $targetPath) {
+	public function saveAttachment($accountId, $folderId, $messageId,
+		$attachmentId, $targetPath) {
 		$mailBox = $this->getFolder($accountId, $folderId);
 
 		$attachmentIds = [$attachmentId];
-		if($attachmentId === 0) {
+		if ($attachmentId === 0) {
 			// Save all attachments
 			/* @var $m IMAPMessage */
 			$m = $mailBox->getMessage($messageId);
-			$attachmentIds = array_map(function($a){
+			$attachmentIds = array_map(function($a) {
 				return $a['id'];
 			}, $m->attachments);
 		}
 
-		foreach($attachmentIds as $attachmentId) {
+		foreach ($attachmentIds as $attachmentId) {
 			$attachment = $mailBox->getAttachment($messageId, $attachmentId);
 
 			$fileName = $attachment->getName();
@@ -306,7 +299,7 @@ class MessagesController extends Controller {
 			$fileExtension = $fileParts['extension'];
 			$fullPath = "$targetPath/$fileName.$fileExtension";
 			$counter = 2;
-			while($this->userFolder->nodeExists($fullPath)) {
+			while ($this->userFolder->nodeExists($fullPath)) {
 				$fullPath = "$targetPath/$fileName ($counter).$fileExtension";
 				$counter++;
 			}
@@ -314,12 +307,12 @@ class MessagesController extends Controller {
 			$newFile = $this->userFolder->newFile($fullPath);
 			$newFile->putContent($attachment->getContents());
 		}
-
 		return new JSONResponse();
 	}
 
 	/**
 	 * @NoAdminRequired
+	 * @TrapError
 	 *
 	 * @param int $accountId
 	 * @param string $folderId
@@ -330,20 +323,20 @@ class MessagesController extends Controller {
 	public function setFlags($accountId, $folderId, $messageId, $flags) {
 		$mailBox = $this->getFolder($accountId, $folderId);
 
-		foreach($flags as $flag => $value) {
+		foreach ($flags as $flag => $value) {
 			$value = filter_var($value, FILTER_VALIDATE_BOOLEAN);
 			if ($flag === 'unseen') {
 				$flag = 'seen';
 				$value = !$value;
 			}
-			$mailBox->setMessageFlag($messageId, '\\'.$flag, $value);
+			$mailBox->setMessageFlag($messageId, '\\' . $flag, $value);
 		}
-
 		return new JSONResponse();
 	}
 
 	/**
 	 * @NoAdminRequired
+	 * @TrapError
 	 *
 	 * @param int $accountId
 	 * @param string $folderId
@@ -356,21 +349,21 @@ class MessagesController extends Controller {
 			$account = $this->getAccount($accountId);
 			$account->deleteMessage(base64_decode($folderId), $id);
 			return new JSONResponse();
-
 		} catch (DoesNotExistException $e) {
 			$this->logger->error("could not delete message <$id> of folder <$folderId>, "
 				. "account <$accountId> because it does not exist");
-			return new JSONResponse([], Http::STATUS_NOT_FOUND);
+			throw $e;
 		}
 	}
 
 	/**
 	 * @param int $accountId
-	 * @return IAccount
+	 * @return Account
 	 */
 	private function getAccount($accountId) {
 		if (!array_key_exists($accountId, $this->accounts)) {
-			$this->accounts[$accountId] = $this->accountService->find($this->currentUserId, $accountId);
+			$this->accounts[$accountId] = $this->accountService->find($this->currentUserId,
+				$accountId);
 		}
 		return $this->accounts[$accountId];
 	}
@@ -391,8 +384,10 @@ class MessagesController extends Controller {
 	 * @param string $folderId
 	 * @return callable
 	 */
-	private function enrichDownloadUrl($accountId, $folderId, $messageId, $attachment) {
-		$downloadUrl = $this->urlGenerator->linkToRoute('mail.messages.downloadAttachment', [
+	private function enrichDownloadUrl($accountId, $folderId, $messageId,
+		$attachment) {
+		$downloadUrl = $this->urlGenerator->linkToRoute('mail.messages.downloadAttachment',
+			[
 			'accountId' => $accountId,
 			'folderId' => $folderId,
 			'messageId' => $messageId,
@@ -439,7 +434,8 @@ class MessagesController extends Controller {
 	 * @return string
 	 */
 	private function buildHtmlBodyUrl($accountId, $folderId, $messageId) {
-		$htmlBodyUrl = $this->urlGenerator->linkToRoute('mail.messages.getHtmlBody', [
+		$htmlBodyUrl = $this->urlGenerator->linkToRoute('mail.messages.getHtmlBody',
+			[
 			'accountId' => $accountId,
 			'folderId' => $folderId,
 			'messageId' => $messageId,
@@ -447,22 +443,6 @@ class MessagesController extends Controller {
 		return $this->urlGenerator->getAbsoluteURL($htmlBodyUrl);
 	}
 
-	/**
-	 * @param integer $accountId
-	 * @param string $folderId
-	 */
-	private function loadMultiple($accountId, $folderId, $ids) {
-		$messages = array_map(function($id) use ($accountId, $folderId){
-			try {
-				return $this->loadMessage($accountId, $folderId, $id);
-			} catch (DoesNotExistException $ex) {
-				return null;
-			}
-		}, $ids);
-
-		return $messages;
-	}
-
 	/**
 	 * @param int $accountId
 	 * @param string $folderId
@@ -471,7 +451,8 @@ class MessagesController extends Controller {
 	 * @param IMailBox $mailBox
 	 * @return array
 	 */
-	private function enhanceMessage($accountId, $folderId, $id, IMAPMessage $m, $mailBox) {
+	private function enhanceMessage($accountId, $folderId, $id, IMAPMessage $m,
+		$mailBox) {
 		$json = $m->getFullMessage($mailBox->getSpecialRole());
 
 		if (isset($json['hasHtmlBody'])) {
