@@ -26,7 +26,6 @@ use Exception;
 use OCA\Mail\Account;
 use OCA\Mail\Db\MailAccount;
 use OCA\Mail\Db\MailAccountMapper;
-use OCA\Mail\Exception\ServiceException;
 use OCA\Mail\Service\DefaultAccount\Manager;
 use OCP\IL10N;
 
@@ -38,7 +37,7 @@ class AccountService {
 	/**
 	 * Cache accounts for multiple calls to 'findByUserId'
 	 *
-	 * @var IAccount[]
+	 * @var Account[]
 	 */
 	private $accounts;
 
@@ -61,7 +60,7 @@ class AccountService {
 
 	/**
 	 * @param string $currentUserId
-	 * @return IAccount[]
+	 * @return Account[]
 	 */
 	public function findByUserId($currentUserId) {
 		if ($this->accounts === null) {
@@ -83,7 +82,7 @@ class AccountService {
 	/**
 	 * @param $currentUserId
 	 * @param $accountId
-	 * @return IAccount
+	 * @return Account
 	 */
 	public function find($currentUserId, $accountId) {
 		if ($this->accounts !== null) {
@@ -95,9 +94,6 @@ class AccountService {
 			throw new Exception("Invalid account id <$accountId>");
 		}
 
-		if ((int) $accountId === UnifiedAccount::ID) {
-			return $this->buildUnifiedAccount($currentUserId);
-		}
 		if ((int) $accountId === Manager::ACCOUNT_ID) {
 			$defaultAccount = $this->defaultAccountManager->getDefaultAccount();
 			if (is_null($defaultAccount)) {
@@ -108,30 +104,10 @@ class AccountService {
 		return new Account($this->mapper->find($currentUserId, $accountId));
 	}
 
-	private function moveMessageOnSameAccount(IAccount $account, $sourceFolderId,
-		$destFolderId, $messageId) {
-		$account->moveMessage(base64_decode($sourceFolderId), $messageId, base64_decode($destFolderId));
-	}
-
-	public function moveMessage($accountId, $folderId, $id, $destAccountId,
-		$destFolderId, $userId) {
-		$sourceAccount = $this->find($userId, $accountId);
-		$destAccount = $this->find($userId, $destAccountId);
-
-		if ($sourceAccount->getId() === $destAccount->getId()) {
-			$this->moveMessageOnSameAccount($sourceAccount, $folderId, $destFolderId, $id);
-		} else {
-			throw new ServiceException('It is not possible to move across accounts yet');
-		}
-	}
-
 	/**
 	 * @param int $accountId
 	 */
 	public function delete($currentUserId, $accountId) {
-		if ((int) $accountId === UnifiedAccount::ID) {
-			return;
-		}
 		if ((int) $accountId === Manager::ACCOUNT_ID) {
 			return;
 		}
@@ -147,8 +123,4 @@ class AccountService {
 		return $this->mapper->save($newAccount);
 	}
 
-	private function buildUnifiedAccount($userId) {
-		return new UnifiedAccount($this, $userId, $this->l10n);
-	}
-
 }
