@@ -18,19 +18,21 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>
  *
  */
+
 namespace OCA\Mail\Service\AutoConfig;
 
 use OCA\Mail\Service\Logger;
 
-abstract class ConnectivityTester {
+class ConnectivityTester {
 
-	const CONNECTION_TIMEOUT = 10;
+	const CONNECTION_TIMEOUT = 5;
 
-	/**
-	 * @var Logger
-	 */
+	/** @var Logger */
 	protected $logger;
 
+	/**
+	 * @param Logger $logger
+	 */
 	public function __construct(Logger $logger) {
 		$this->logger = $logger;
 	}
@@ -40,9 +42,9 @@ abstract class ConnectivityTester {
 	 * @param integer $port
 	 * @return bool
 	 */
-	protected function canConnect($url, $port) {
+	public function canConnect($url, $port) {
 		$this->logger->debug("attempting to connect to <$url> on port <$port>");
-		$fp = fsockopen($url, $port, $error, $errorstr, self::CONNECTION_TIMEOUT);
+		$fp = @fsockopen($url, $port, $error, $errorstr, self::CONNECTION_TIMEOUT);
 		if (is_resource($fp)) {
 			fclose($fp);
 			$this->logger->debug("connection to <$url> on port <$port> established");
